@@ -287,7 +287,11 @@ class QiwiWrapper:
                 if transaction.comment == comment and transaction.to_account == sender_number:
                     return True
                 elif comment and sender_number:
-                    return False
+                    continue
                 elif transaction.to_account == sender_number:
                     return True
+                elif sender_number:
+                    continue
+                elif transaction.comment == comment:
+                    return True
         return False
